@@ -4,8 +4,7 @@ import pandas as pd
 import pstats
 from sklearn.model_selection import train_test_split
 
-from causalml.inference.tree import UpliftTreeClassifier
-from causalml.inference.tree import UpliftRandomForestClassifier
+from causalml.inference.tree import UpliftTreeClassifier, UpliftRandomForestClassifier
 from causalml.metrics import get_cumgain
 
 from .const import RANDOM_SEED, N_SAMPLE, CONTROL_NAME, TREATMENT_NAMES, CONVERSION
@@ -25,7 +24,8 @@ def test_UpliftRandomForestClassifier(generate_classification_data):
     # Train the UpLift Random Forest classifier
     uplift_model = UpliftRandomForestClassifier(
         min_samples_leaf=50,
-        control_name=TREATMENT_NAMES[0]
+        control_name=TREATMENT_NAMES[0],
+        random_state=RANDOM_SEED
     )
 
     uplift_model.fit(df_train[x_names].values,
@@ -33,7 +33,7 @@ def test_UpliftRandomForestClassifier(generate_classification_data):
                      y=df_train[CONVERSION].values)
 
     y_pred = uplift_model.predict(df_test[x_names].values)
-    result = pd.DataFrame(y_pred, columns=uplift_model.classes_)
+    result = pd.DataFrame(y_pred, columns=uplift_model.classes_[1:])
 
     best_treatment = np.where((result < 0).all(axis=1),
                               CONTROL_NAME,
@@ -57,7 +57,7 @@ def test_UpliftRandomForestClassifier(generate_classification_data):
         is_treated=1 - actual_is_control[synthetic],
         conversion=df_test.loc[synthetic, CONVERSION].values,
         uplift_tree=synth.max(axis=1)
-    ).drop(columns=list(uplift_model.classes_))
+    ).drop(columns=list(uplift_model.classes_[1:]))
 
     cumgain = get_cumgain(auuc_metrics,
                           outcome_col=CONVERSION,
@@ -75,7 +75,7 @@ def test_UpliftTreeClassifier(generate_classification_data):
                                          random_state=RANDOM_SEED)
 
     # Train the UpLift Random Forest classifier
-    uplift_model = UpliftTreeClassifier(control_name=TREATMENT_NAMES[0])
+    uplift_model = UpliftTreeClassifier(control_name=TREATMENT_NAMES[0], random_state=RANDOM_SEED)
 
     pr = cProfile.Profile(subcalls=True, builtins=True, timeunit=.001)
     pr.enable()
@@ -83,14 +83,13 @@ def test_UpliftTreeClassifier(generate_classification_data):
                      treatment=df_train['treatment_group_key'].values,
                      y=df_train[CONVERSION].values)
 
-    _, _, _, y_pred = uplift_model.predict(df_test[x_names].values,
-                                           full_output=True)
+    y_pred = uplift_model.predict(df_test[x_names].values)
     pr.disable()
     with open('UpliftTreeClassifier.prof', 'w') as f:
         ps = pstats.Stats(pr, stream=f).sort_stats('cumulative')
         ps.print_stats()
 
-    result = pd.DataFrame(y_pred)
+    result = pd.DataFrame(y_pred, columns=uplift_model.classes_)
     result.drop(CONTROL_NAME, axis=1, inplace=True)
 
     best_treatment = np.where((result < 0).all(axis=1),
@@ -134,12 +133,13 @@ def test_UpliftTreeClassifier_feature_importance(generate_classification_data):
                                          random_state=RANDOM_SEED)
 
     # Train the upLift classifier
-    uplift_model = UpliftTreeClassifier(control_name=TREATMENT_NAMES[0])
+    uplift_model = UpliftTreeClassifier(control_name=TREATMENT_NAMES[0], random_state=RANDOM_SEED)
     uplift_model.fit(df_train[x_names].values,
                      treatment=df_train['treatment_group_key'].values,
                      y=df_train[CONVERSION].values)
 
     assert hasattr(uplift_model, 'feature_importances_')
+    assert (np.all(uplift_model.feature_importances_ >= 0))
     num_non_zero_imp_features = sum([1 if imp > 0 else 0 for imp in uplift_model.feature_importances_])
 
     def getNonleafCount(node):
